@@ -2,8 +2,10 @@
 from .aws_tools import *
 from .memory_reduction import *
 from .general_functions import *
+from .batch_transform_tools import *
 
 __all__ = (aws_tools.__all__ +
            memory_reduction.__all__+
-           general_functions.__all__
+           general_functions.__all__+
+           batch_transform_tools.__all__
            )
