@@ -132,14 +132,26 @@ def one_hot_encoding(df):
     return df
 
 
-def align_dataframe_with_sample(df, sample, fillvalue=0):
-    logger.info('aligning dataframe with sample')
-    _, df = sample.align(
-        df,
-        join='left',
-        axis=1,
-        fill_value=fillvalue
-    )
+def align_dataframe_with_sample(df, sample, fillvalue=0, predictions_flag=None):
+    if predictions_flag is None:
+        logger.info('aligning dataframe with sample')
+        _, df = sample.align(
+            df,
+            join='left',
+            axis=1,
+            fill_value=fillvalue)
+    else:
+        idlead_col = df['idLead']
+        idcampaign_col = df['idCampaign']
+        logger.info('aligning dataframe with sample')
+        _, df = sample.align(
+            df,
+            join='left',
+            axis=1,
+            fill_value=fillvalue)
+
+        df.insert(loc=0, value=idlead_col, column='idLead')
+        df.insert(loc=1, value=idcampaign_col, column='idCampaign')
     return df
 
 
@@ -594,8 +606,8 @@ def create_class_dictionaries(df_original, mapping_dicts, column: str):
     df.loc[df['IDEmailStatus'] == 14, 'IDEmailStatus'] = 1
     df.loc[df['IDEmailStatus'] == 31, 'IDEmailStatus'] = 1
     groupby = df.groupby(column, dropna=False).agg(BV=('BV', 'mean'),
-                                                         Conversions=('IDEmailStatus', 'mean')
-                                                         )
+                                                   Conversions=('IDEmailStatus', 'mean')
+                                                   )
     groupby = groupby.reset_index()
     logger.info(f"{groupby.head()}")
     list_dict = groupby.to_dict(orient='records')
@@ -606,9 +618,9 @@ def create_class_dictionaries(df_original, mapping_dicts, column: str):
         bv_dict[element[column]] = element['BV']
 
     bv_col = column + "_bv"
-    mapping_dicts[bv_col]=bv_dict
-    prob_col=column+"_prob"
-    mapping_dicts[prob_col]=conversion_dict
+    mapping_dicts[bv_col] = bv_dict
+    prob_col = column + "_prob"
+    mapping_dicts[prob_col] = conversion_dict
     return mapping_dicts
 
 
@@ -642,8 +654,6 @@ def map_conv_prob_using_dictionary(df, mapping_dicts, column: str, drop: bool =
     :return df: processed Dataset
     """
 
-    if column not in df.columns:
-        raise Exception("MXType column not preset ( Check Caps)")
     logger.info(f'mapping bv and prob dicts for {column}')
     bv_col = column + "_bv"
     df[bv_col] = df[column].map(mapping_dicts[bv_col])
